# PESummary

## Release status

[![PyPI version](https://badge.fury.io/py/pesummary.svg)](http://badge.fury.io/py/pesummary)
[![Conda version](https://img.shields.io/conda/vn/conda-forge/pesummary.svg)](https://anaconda.org/conda-forge/pesummary/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pesummary)](https://img.shields.io/pypi/dm/pesummary)
[![Total Downloads](https://anaconda.org/conda-forge/pesummary/badges/downloads.svg)](https://anaconda.org/conda-forge/pesummary/badges/downloads.svg)

[![License](https://img.shields.io/pypi/l/pesummary.svg)](https://choosealicense.com/licenses/mit/)
[![Python versions](https://img.shields.io/pypi/pyversions/pesummary.svg)](https://img.shields.io/pypi/pyversions/pesummary.svg)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4771187.svg)](https://doi.org/10.5281/zenodo.4771187)

## Development status

[![Pipeline Status](https://git.ligo.org/lscsoft/pesummary/badges/master/pipeline.svg)](https://git.ligo.org/lscsoft/pesummary/commits/master)
[![Coverage report](https://docs.ligo.org/lscsoft/pesummary/coverage_badge.svg)](https://docs.ligo.org/lscsoft/pesummary/htmlcov/index.html)

This package helps the user to generate summary webpages to visualise the output from any sample generating code.

 * [Installation instructions](https://docs.ligo.org/lscsoft/pesummary/installation.html)
 * [Documentation](https://docs.ligo.org/lscsoft/pesummary)
 * [Issue Tracker](https://git.ligo.org/lscsoft/pesummary/issues)
